ReaderTTSVoice class

Implemented types
Annotations

Constructors

ReaderTTSVoice({required String identifier, required String name, required String language, required bool networkRequired, required TTSVoiceGender gender, required TTSVoiceQuality? quality, required bool? active})
factory
ReaderTTSVoice.fromJson(Map<String, dynamic> json)
factory

Properties

active bool?
final
gender TTSVoiceGender
final
hashCode int
The hash code for this object.
no setterinherited
identifier String
final
language String
final
name String
final
networkRequired bool
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
quality TTSVoiceQuality?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

copyWith({String? identifier, String? name, String? language, bool? networkRequired, TTSVoiceGender? gender, TTSVoiceQuality? quality, bool? active}) ReaderTTSVoice
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes the object to its JSON representation.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited