ReadiumReaderWidgetInterface class abstract

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyDecorations(String id, List<ReaderDecoration> decorations) Future<void>
Apply decorations
go(Locator locator, {required bool isAudioBookWithText, bool animated = false}) Future<void>
Call to navigate the reader to a location.
goBackward({bool animated = true}) Future<void>
Go to previous page.
goForward({bool animated = true}) Future<void>
Go to next page.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setEPUBPreferences(EPUBPreferences preferences) Future<void>
Set EPUB preferences
setPDFPreferences(PDFPreferences preferences) Future<void>
Set PDF preferences
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited