methodChannel property
The method channel used to interact with the native platform.
Implementation
@visibleForTesting
MethodChannel methodChannel = const MethodChannel('dk.nota.flutter_readium/main');
The method channel used to interact with the native platform.
@visibleForTesting
MethodChannel methodChannel = const MethodChannel('dk.nota.flutter_readium/main');