readerStatusChannel property
The event channel used to receive text Locator changes from the native platform.
Implementation
@visibleForTesting
EventChannel readerStatusChannel = const EventChannel('dk.nota.flutter_readium/reader-status');
The event channel used to receive text Locator changes from the native platform.
@visibleForTesting
EventChannel readerStatusChannel = const EventChannel('dk.nota.flutter_readium/reader-status');