textLocatorChannel property
The event channel used to receive text Locator changes from the native platform.
Implementation
@visibleForTesting
EventChannel textLocatorChannel = const EventChannel('dk.nota.flutter_readium/text-locator');
The event channel used to receive text Locator changes from the native platform.
@visibleForTesting
EventChannel textLocatorChannel = const EventChannel('dk.nota.flutter_readium/text-locator');