ReadiumReaderStatus enum
Indicates the current reader widget status.
Values
- loading → const ReadiumReaderStatus
-
The reader is loading content.
- ready → const ReadiumReaderStatus
-
The reader is ready
- closed → const ReadiumReaderStatus
-
The reader is closed
- reachedEndOfPublication → const ReadiumReaderStatus
-
The reader has reached the end of the publication.
- error → const ReadiumReaderStatus
-
An error has occurred in the reader.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasReachedEndOfPublication → bool
-
Whether the reader has reached the end of the publication.
no setter
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isClosed → bool
-
Whether the reader has been closed.
no setter
- isError → bool
-
Whether the reader is in an error state.
no setter
- isLoading → bool
-
Whether the reader is in the loading state.
no setter
- isReady → bool
-
Whether the reader is ready for interaction.
no setter
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
optFromString(
String status) → ReadiumReaderStatus? -
Returns the ReadiumReaderStatus matching
status(case-insensitive), ornullif unknown.
Constants
-
values
→ const List<
ReadiumReaderStatus> - A constant List of the values in this enum, in order of their declaration.